@@ -34,14 +34,15 @@ export type QueryLibraryContextType = {
   onSave?: () => void;
 
   /**
-   * Returns a predefined small button that can be used to save a query to the library.
+   * Returns both save and replace action buttons that can be used to save or replace a query to the library.
    * @param query
    */
-  renderSaveQueryButton: (
+  renderSavedQueryButtons: (
     query: DataQuery,
     app?: CoreApp,
     onUpdateSuccess?: () => void,
-    onSelectQuery?: (query: DataQuery) => void
+    onSelectQuery?: (query: DataQuery) => void,
+    datasourceFilters?: string[]
   ) => ReactNode;
 
   /**
@@ -70,6 +71,7 @@ export type QueryLibraryContextType = {
     contextOverride?: string
   ) => void;
   setNewQuery: (query?: QueryTemplate) => void;
+  onSelectQuery: (query: DataQuery) => void;
 };
 
 export const QueryLibraryContext = createContext<QueryLibraryContextType>({
@@ -80,7 +82,7 @@ export const QueryLibraryContext = createContext<QueryLibraryContextType>({
   setNewQuery: () => {},
   onSave: () => {},
 
-  renderSaveQueryButton: () => {
+  renderSavedQueryButtons: () => {
     return null;
   },
 
@@ -91,6 +93,7 @@ export const QueryLibraryContext = createContext<QueryLibraryContextType>({
   queryLibraryEnabled: false,
   context: 'unknown',
   triggerAnalyticsEvent: () => {},
+  onSelectQuery: () => {},
 });
 
 export function useQueryLibraryContext() {
